
College Board Picture Lab and Steganography Lab for 2D Arrays
=============================================================

.. |Picture lab| raw:: html

   <a href= "https://secure-media.collegeboard.org/digitalServices/pdf/ap/picture-lab-studentguide.pdf" style="text-decoration:underline" target="_blank" >Picture Lab</a>

.. |Steganography lab| raw:: html

   <a href= "https://apcentral.collegeboard.org/pdf/ap-computer-science-a-steganography-lab-student-guide.pdf" style="text-decoration:underline" target="_blank" >Steganography Lab</a>

The |Picture Lab| is a fun lab that you may have started in 8.2 and can finish in the next pages:

.. toctree::
   :maxdepth: 3

   pictureLabA1toA3.rst
   pictureLabA4.rst
   pictureLabA5.rst
   pictureLabA6.rst
   pictureLabA7.rst
   pictureLabA8.rst
   pictureLabA9.rst

There is also a new College Board called the |Steganography lab| that continues on from the Picture Lab and explores hiding messages in images. The teacher guide and the code files are available in the AP Course Audit Portal.
